diff --git a/.travis.yml b/.travis.yml
index b30af7e..9197690 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -11,7 +11,7 @@ script:
   - PATH=/usr/lib/postgresql/$PGVER/bin/:$PATH ./localtests.sh
 
 after_failure:
-  - cat regressiondata/regression.diffs
+  - cat regression.diffs
 
 env:
   - PGVER=9.1
diff --git a/localtests.sh b/localtests.sh
index d43e15f..956e300 100755
--- a/localtests.sh
+++ b/localtests.sh
@@ -2,17 +2,55 @@
 
 # Create a clean PostgreSQL cluster for our testing
 
-TESTDIR="$(pwd)/regressiondata"
+TESTDIR="$(pwd)/tmp_check"
 export PGPORT=$((10240 + RANDOM / 2))
-export PGDATA="$TESTDIR/pg"
+export PGDATA="$TESTDIR/data"
 
 rm -rf "$TESTDIR"
+
+# Create a minimal PostgreSQL installation, by copying an existing
+# installation. This is a replacement for doing "make install" in the
+# PostgreSQL source tree, for when you don't have the source tree available.
+#
+# The minimum we need to copy from the existing installation are server 'lib'
+# and 'share' directories, and a few binaries.
+#
+# Note that 'pg_config --libdir' is the path to client-side libraries, i.e.
+# libpq, and we don't want to copy that. (on many distributions, libdir points
+# to just /usr/lib, and we certainly don't want to copy that in whole).
+# Also note that we cannot use symlinks for the binaries, because the binaries
+# look at the absolute path they are run from to find the rest of the files
+# they need.
+
+TMP_INSTALL="$TESTDIR/install"
+
+bindir=`pg_config --bindir`
+pkglibdir=`pg_config --pkglibdir`
+sharedir=`pg_config --sharedir`
+
+mkdir -p "$TMP_INSTALL"
+mkdir -p "$TMP_INSTALL$bindir"
+mkdir -p "$TMP_INSTALL$pkglibdir"
+mkdir -p "$TMP_INSTALL$sharedir"
+
+cp -a $bindir/postgres $TMP_INSTALL$bindir
+cp -a $bindir/initdb $TMP_INSTALL$bindir
+cp -a $bindir/pg_ctl $TMP_INSTALL$bindir
+cp -a $pkglibdir/* $TMP_INSTALL$pkglibdir
+cp -a $sharedir/* $TMP_INSTALL$sharedir
+
+export PATH=$TMP_INSTALL$bindir:$PATH
+
+# Install pgmemcache to the temporary installation
+make install DESTDIR=$TMP_INSTALL
+
+# Set up a temporary cluster
 mkdir -p "$PGDATA"
 
 initdb -E UTF-8 --no-locale
+# XXX: Should use pg_config --config-auth to lock down the cluster
 sed -e "s%^#port =.*%port = $PGPORT%" \
     -e "s%^#\(unix_socket_director[a-z]*\) =.*%\1 = '$PGDATA'%" \
-    -e "s%^#dynamic_library_path = .*%dynamic_library_path = '$(pwd):\$libdir'%" \
     -e "s%^#fsync = .*%fsync = off%" \
     -e "s%^#synchronous_commit = .*%synchronous_commit = off%" \
     -i "$PGDATA/postgresql.conf"
@@ -20,15 +58,5 @@ pg_ctl -l "$PGDATA/log" start
 while [ ! -S "$PGDATA/.s.PGSQL.$PGPORT" ]; do sleep 2; done
 trap "pg_ctl stop -m immediate" EXIT
 
-# It's not possible to override the extension path, so we'll just execute
-# the extension SQL directly after mangling it a bit with sed
-
-cp -a Makefile test.sql sql/ expected/ "$TESTDIR"
-sed -e "s%MODULE_PATHNAME%pgmemcache%" \
-    -e "/CREATE EXTENSION/d" -e "/^--/d" -e "/^$/d" \
-    "ext/pgmemcache.sql" > "$TESTDIR/sql/init.sql"
-cp "$TESTDIR/sql/init.sql" "$TESTDIR/expected/init.out"
-
-# Run the actual tests
-
-make -C "$TESTDIR" installcheck REGRESS_OPTS="--host=$PGDATA --port=$PGPORT"
+# Run the actual tests in the temporary cluster.
+make installcheck REGRESS_OPTS="--host=$PGDATA --port=$PGPORT"
